#!bin/bash

# TE-SYSTEMS GmbH
# Script date: May 2024

# This script performs the following actions:
#	- Import the LOD license to anynode. 

# This script uses cat, curl and jq. 
#  In case curl does not trust your web certificate, this script will not work. Please
#  edit all curl commands after the ---- Start of script ---- part to make it work.
# 	- curl might not be installed by default - to install curl use sudo apt install curl in terminal
#	- cat should be installed with linux by default
#	- jq might not be installed by default - to install jq use sudo apt install jq in terminal

# In order to use the script, some variables must be adjusted.
#	- The path to the REST API PowerShell-Module must be set.
#		By default, the Powershell-Modul is in the folder directly above the one in which this script is located.
#	- The address of  anynode must be set.
#		By default the address is set to localhost.

#   --- LOD license import ---
#   - An email address must be specified for LOD activation.
#   - A company name must be specified for LOD activation.
#	- The LOD Key must be entered.

# Please check all existing parameters before starting the script.

#---- Variables ----
# Define anynode's address and port.
anynode='127.0.0.1:443'

# Set the credentials of an anynode user with configuration write access and REST API access.
cred='USERNAME:PASSWORD'

# Set the required details of the LOD.
emailAddress="EMAIL"
companyName="COMPANY_NAME"
lodKey="LOD_KEY"

# ---- Start of script ----
# The next 4 lines check whether a secure connection can be established.
# In order to establish an insecure connection, the following must be adjusted
#	- Delete the following 4 lines or comment them out
#	- Adjust all following curl commands 

ssl=$(curl -s https$anynode)
if [[ $ssl ==  ]]; then
  echo 'No secure connection could be established to anynode.'
fi

# Use the given data to create the lodDataObject
lodData=$(cat EOF
{
	emailAddress ${emailAddress},
	companyName ${companyName},
	lodKey ${lodKey}
}
EOF
)

# Get the devices System ID's and select the first
systemIds=$(curl -k -s -u ${cred} -X GET http${anynode}apilicensessystemIdsgetversion=0)
licensingDeviceID=$(echo $systemIds  jq '.[0].id'  sed 's^(.)$1')

# Add the System ID of the first device to lodData
updatedLodData=$(echo $lodData  jq --arg licensingDeviceID $licensingDeviceID ' . + { licensingDevice $licensingDeviceID }')

# Import the LOD 
# If you want to use an insecure connection, add the -k argument for curl
echo --- Importing LOD license to anynode - this can take up to 30 seconds.
curl -k -s -u ${cred} -H Content-Type applicationjson -d ${updatedLodData} -X PUT http${anynode}apilicensesimportLodversion=0  devnull
echo --- LOD license successfully imported.
