#!bin/bash

# TE-SYSTEMS GmbH
# Script date: May 2024

# This script performs the following actions:
# 	- Import the configuration for which the path was defined into the defined anynode.
#	- If so defined, the configuration is committed to anynode.

# This script uses curl
#  In case curl does not trust your web certificate, this script will not work. Please
#  edit all curl commands after the ---- Start of script ---- part to make it work.
# 	- curl might not be installed by default - to install curl use "sudo apt install curl" in terminal

# In order to use the script, some variables must be adjusted.
#	- The path to the REST API PowerShell-Module must be set.
#		By default, the Powershell-Modul is in the folder directly above the one in which this script is located.
#	- The address of  anynode must be set.
#		By default the address is set to localhost.

#   --- Config import ---
#   - The path to the .xzconfig file that is to be imported must be set.
#   - It must be determined whether the imported configuration should be comitted.
#		In an unadapted state, the imported configuration won't be committed.

# Please check all existing parameters before starting the script.

#---- Variables ----
# Define anynode's address and port.
anynode='127.0.0.1:443'

# Set the credentials of an anynode user with configuration write access and REST API access.
cred='USERNAME:PASSWORD'

# Path to the anynode config file to import.
configPath="PATH_TO_CONFIG"

# Set this parameter to "true" to commit the imported config automatically - disabled by default
commitConfig=false

# ---- Start of script ----
# The next 4 lines check whether a secure connection can be established.
# In order to establish an insecure connection, the following must be adjusted
#	- Delete the following 4 lines or comment them out
#	- Adjust all following curl commands 

ssl=$(curl -s https://$anynode/)
if [[ $ssl == "" ]]; then
  echo 'No secure connection could be established to anynode.'
fi

# Importing the config to anynode.
# If you want to use an insecure connection, add the -k argument for curl
echo "--- Importing the given configuration to anynode."
curl -k -s -u ${cred} -H "Content-Type: multipart/form-data" -X PUT http://${anynode}/api/anynodeConfig/set?version=0 -F "file=@${configPath}"

# Commiting imported config if variable "$commitConfig" is set to "true"
# If you want to use an insecure connection, add the -k argument for curl
if [ $commitConfig = true ] ; then
echo "--- Committing the configuration."
curl -k -s -u ${cred} -X POST http://{$anynode}/api/anynodeConfig/commit?version=0
echo "--- Committed anynode config to ${anynode} successfully."
fi
